'use strict';

var chalk = require('chalk');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var chalk__default = /*#__PURE__*/_interopDefault(chalk);

const timers = /* @__PURE__ */ new Map();
function createLogger(prefix, options = {}) {
  const { level = "info" } = options;
  const formatPrefix = () => chalk__default.default.cyan(`[${prefix}]`);
  const formatTime = (ms) => chalk__default.default.gray(`(${ms}ms)`);
  return {
    info: (message, ...args) => {
      console.log(`${formatPrefix()} ${message}`, ...args);
    },
    warn: (message, ...args) => {
      console.warn(`${formatPrefix()} ${chalk__default.default.yellow("warning")} ${message}`, ...args);
    },
    error: (message, ...args) => {
      console.error(`${formatPrefix()} ${chalk__default.default.red("error")} ${message}`, ...args);
    },
    success: (message, ...args) => {
      console.log(`${formatPrefix()} ${chalk__default.default.green("\u2713")} ${message}`, ...args);
    },
    report: (stats) => {
      const { total, success, skipped, failed } = stats;
      const hasIssues = failed > 0 || skipped > 0;
      console.log("\n" + formatPrefix() + " " + chalk__default.default.bold("Build Summary:"));
      const rows = [
        [`  ${chalk__default.default.bold("Total files:")}`, `${total}`],
        [`  ${chalk__default.default.bold("Processed:")}`, `${chalk__default.default.green(success)}`],
        [`  ${chalk__default.default.bold("Skipped:")}`, `${skipped > 0 ? chalk__default.default.yellow(skipped) : skipped}`],
        [`  ${chalk__default.default.bold("Failed:")}`, `${failed > 0 ? chalk__default.default.red(failed) : failed}`]
      ];
      rows.forEach(([label, value]) => {
        console.log(`${label.padEnd(20)}${value}`);
      });
      if (hasIssues) {
        console.log("\n" + formatPrefix() + " " + chalk__default.default.yellow("\u26A0\uFE0F  Some files were not processed successfully"));
      } else {
        console.log("\n" + formatPrefix() + " " + chalk__default.default.green("\u2728 All files processed successfully"));
      }
      console.log();
    },
    time: (label) => {
      timers.set(label, performance.now());
    },
    timeEnd: (label) => {
      const start = timers.get(label);
      if (start) {
        const duration = Math.round(performance.now() - start);
        console.log(`${formatPrefix()} ${label} ${formatTime(duration)}`);
        timers.delete(label);
      }
    },
    verbose: (message, ...args) => {
      if (level === "verbose") {
        console.log(`${formatPrefix()} ${chalk__default.default.gray(message)}`, ...args);
      }
    }
  };
}

exports.createLogger = createLogger;
//# sourceMappingURL=logger.js.map
//# sourceMappingURL=logger.js.map